---
feature_story: FS_99_81_19_25
feature_title: no space in options
feature_status: TBD
---

At the moment, `argrelay` does not support (white) space chars in arg value options.

In fact, current impl of FS_71_87_33_52 `help_hint` feature relies on that by removing
`help_hint` (trailing part of string after first space) in case of single option.

This also encourages to keep command entry more convenient without quoting args.

Quoting will complicate parsing - see FS_92_75_93_01 clean command line.
